@@ -15,7 +15,7 @@ from past.builtins import long
 # Import local modules
 from rayvision_api.constants import MODIFIABLE_PARAM
 from rayvision_api.exception import RayvisionError
-
+from rayvision_api.utils import json_load
 
 # pylint: disable=useless-object-inheritance
 class RayvisionCheck(object):
@@ -102,26 +102,30 @@ class RayvisionCheck(object):
             task_info["task_info"]["project_id"] = self.api.check_and_add_project_name(task_info["task_info"]["project_name"])
         return task_info
 
-    def execute(self, task_info, upload_info):
+    def execute(self, task_json, upload_json):
         """Check asset configuration information.
 
         Check the scene for problems and filter unwanted configuration
         information.
 
-        Returns:
-            str: task id.
-
         """
+        task_info = json_load(task_json)
+        upload_info = json_load(upload_json)
         self.logger.info('[Rayvision_utils check start .....]')
-        task_info = self.check_task_info(task_info)
-        upload_info = upload_info or {}
+        self.task_info = self.check_task_info(task_info)
+        self.upload_info = upload_info or {}
 
         self.check_error_warn_info()
         self.is_scene_have_error()  # Check error.
-        scene_info_render = task_info.get("scene_info_render") or task_info["scene_info"]
-        self._edit_param_and_write(scene_info_render, task_info["task_info"], upload_info)
+        task_id = self.write()
+        return task_id
+
+    def write(self):
+        """Check and write to a json file."""
+        scene_info_render = self.task_info.get("scene_info_render") or self.task_info["scene_info"]
+        self._edit_param_and_write(scene_info_render, self.task_info["task_info"], self.upload_info)
         self.logger.info('[Rayvision_utils check end .....]')
-        return task_info["task_info"]["task_id"]
+        return self.task_info["task_info"]["task_id"]
 
     def check_error_warn_info(self, language='0'):
         """Check the error in the analysis scenario.
